@@ -1,14 +1,33 @@
+"""
+CodeClone — AST and CFG-based code clone detector for Python
+focused on architectural duplication.
+
+Copyright (c) 2026 Den Rozhnovskiy
+Licensed under the MIT License.
+"""
+
 from __future__ import annotations
 
 from pathlib import Path
 from typing import Iterable
 
 DEFAULT_EXCLUDES = (
-    ".git", ".venv", "venv", "__pycache__", "site-packages",
-    "migrations", "alembic", "dist", "build", ".tox",
+    ".git",
+    ".venv",
+    "venv",
+    "__pycache__",
+    "site-packages",
+    "migrations",
+    "alembic",
+    "dist",
+    "build",
+    ".tox",
 )
 
-def iter_py_files(root: str, excludes: tuple[str, ...] = DEFAULT_EXCLUDES) -> Iterable[str]:
+
+def iter_py_files(
+    root: str, excludes: tuple[str, ...] = DEFAULT_EXCLUDES
+) -> Iterable[str]:
     rootp = Path(root)
     for p in rootp.rglob("*.py"):
         parts = set(p.parts)
@@ -16,6 +35,7 @@ def iter_py_files(root: str, excludes: tuple[str, ...] = DEFAULT_EXCLUDES) -> It
             continue
         yield str(p)
 
+
 def module_name_from_path(root: str, filepath: str) -> str:
     rootp = Path(root).resolve()
     fp = Path(filepath).resolve()
@@ -25,4 +45,4 @@ def module_name_from_path(root: str, filepath: str) -> str:
     # __init__.py -> package name
     if stem.name == "__init__":
         stem = stem.parent
-    return ".".join(stem.parts)
\ No newline at end of file
+    return ".".join(stem.parts)
